"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const crunchFeaturePolicyHeader_1 = __importDefault(require("./crunchFeaturePolicyHeader"));
const crunchPermissionsPolicyHeader_1 = __importDefault(require("./crunchPermissionsPolicyHeader"));
const PermissionsPolicy_1 = __importDefault(require("./PermissionsPolicy"));
function reduceDirectives(supportedDirectives, permissionsPolicy, defaultValue) {
    if (permissionsPolicy === false) {
        return {};
    }
    return supportedDirectives.reduce((accumulator, directive) => {
        if (permissionsPolicy[directive] !== false) {
            accumulator[directive] = permissionsPolicy[directive] || defaultValue;
        }
        return accumulator;
    }, {});
}
function buildPermissionsPolicyHeaders(options = {}) {
    const { permissionsPolicy = {}, permissionsPolicyDirectiveSupport = ['proposed', 'standard'], } = options;
    if (permissionsPolicy === false) {
        return [];
    }
    const supportedDirectives = Array.from(new Set(permissionsPolicyDirectiveSupport.map(directiveSet => PermissionsPolicy_1.default[directiveSet]).flat()));
    return [
        {
            key: 'Feature-Policy',
            value: (0, crunchFeaturePolicyHeader_1.default)(reduceDirectives(supportedDirectives, permissionsPolicy, "'none'"))
        },
        {
            key: 'Permissions-Policy',
            value: (0, crunchPermissionsPolicyHeader_1.default)(reduceDirectives(supportedDirectives, permissionsPolicy, '')),
        },
    ];
}
exports.default = buildPermissionsPolicyHeaders;
