"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const buildCSPHeaders_1 = __importDefault(require("./buildCSPHeaders"));
const buildPermissionsPolicyHeaders_1 = __importDefault(require("./buildPermissionsPolicyHeaders"));
function makeHeaderObj(key, value, defaultValue) {
    if (value === false) {
        return undefined;
    }
    return {
        key,
        value: value || defaultValue
    };
}
function nextSafe(options = {}) {
    const { contentTypeOptions = false, contentSecurityPolicy = {}, frameOptions = false, permissionsPolicy = {}, permissionsPolicyDirectiveSupport, isDev = false, referrerPolicy = false, xssProtection = false, } = options;
    return [
        ...(0, buildCSPHeaders_1.default)({ contentSecurityPolicy, isDev }),
        ...(0, buildPermissionsPolicyHeaders_1.default)({
            permissionsPolicy,
            permissionsPolicyDirectiveSupport,
            isDev,
        }),
        makeHeaderObj('Referrer-Policy', referrerPolicy, 'no-referrer'),
        makeHeaderObj('X-Content-Type-Options', contentTypeOptions, 'nosniff'),
        makeHeaderObj('X-Frame-Options', frameOptions, 'DENY'),
        makeHeaderObj('X-XSS-Protection', xssProtection, '1; mode=block'),
    ]
        // Filter out header values that have resolved to falsy
        .filter((header) => Boolean(header));
}
exports.default = nextSafe;
